# Generated by roxygen2: do not edit by hand

S3method(print,statcan_chat_result)
export(statcan_chat)
export(statcan_chat_continue)
export(statcan_data)
export(statcan_download_data)
export(statcan_find)
export(statcan_search)
